@@ -166,6 +166,9 @@ def save_image(items):
     """ filter that saves a PIL object into an image file """
     for item in items:
         logger.debug(f"saving image {item['origin']}")
+        if "copymode" in item:
+            copy_file([item])
+            continue
         try:
             quality = item["quality"]
         except KeyError:
@@ -211,7 +214,7 @@ def move(fro, to):
         shutil.move(fro, to)
         logger_indented.info(f"moved {fro} -> {to}")
     except FileNotFoundError:
-        raise FileNotFoundError("No file/dir at notification origin!")
+        logger.error("No file/dir at notification origin!")
 
 
 ################################
@@ -322,10 +325,9 @@ def handle_subpages(items):
                     logger_indented.debug(f"rendered subpage {sub_page_item['origin']}")
                     item["meta"]["sub_pages"].append(rendered_subpage["output"])
             except FileNotFoundError:
-                raise FileNotFoundError("Specified subpage does not exist.")
+                logger.error("Specified subpage not found.")
             except IndexError:    # Path found nothing
-                raise IndexError("No subpages at specified location.")
-
+                logger.error("No subpage at specified location.")
         yield item
 
 
