@@ -3,13 +3,14 @@ auto-generate category pages from "collection"
 meta-tags on the pages
 """
 import glob
-from os import walk, sep
+import yaml
+from os import sep, walk
 from os.path import join, getmtime, dirname, splitext
 from watchdog.events import FileModifiedEvent
 from barely.plugins import PluginBase
 from barely.core.EventHandler import EventHandler as EH
 from barely.plugins.PluginManager import PluginManager as PM
-from barely.core.ProcessingPipeline import parse_meta, parse_content, render_page, read_file, write_file
+from barely.core.ProcessingPipeline import parse_meta, parse_content, render_page, read_file, write_file, hook_plugins
 
 
 class Collections(PluginBase):
@@ -60,15 +61,19 @@ class Collections(PluginBase):
 
                 collectible = {}
                 collectible["title"] = item["meta"]["title"]
-                collectible["preview"] = item["content"][:self.plugin_config["SUMMARY_LENGTH"]] + "..."
                 collectible["raw"] = item["content_raw"]
                 collectible["href"] = item["destination"].replace(self.config["ROOT"]["WEB"], "", 1).replace("\\", "/")
                 collectible["timestamp"] = getmtime(item["origin"])
 
+                # is there an existing summary? probably a better preview
+                try:
+                    collectible["preview"] = item["meta"]["summary"]
+                except KeyError:
+                    collectible["preview"] = item["content"][:self.plugin_config["SUMMARY_LENGTH"]] + "..."
+
                 # we'd also really like to get the first image of the blog
                 if "title_image" in item["meta"]:
-                    img_abspath = join(dirname(item["destination"].replace(self.config["ROOT"]["WEB"], "", 1)), item["meta"]["title_image"]).replace("\\", "/")
-                    collectible["image"] = img_abspath
+                    collectible["image"] = item["meta"]["title_image"]
 
                 # for integration with Timestamps
                 if "edited" in item["meta"]:
@@ -145,11 +150,12 @@ class Collections(PluginBase):
                     "content": "",
                     "content_raw": "",
                     "action": "collected",
-                    "origin": col_name
+                    "origin": col_name,
+                    "extension": self.config["PAGE_EXT"]
                 }
 
                 # mini pipeline, only the necessary steps
-                write_file(render_page(parse_meta([page])))
+                write_file(render_page(hook_plugins(parse_meta([page]))))
 
         if self.plugin_config["OVERVIEW_TEMPLATE"]:
             # order collections by their size
@@ -172,7 +178,8 @@ class Collections(PluginBase):
                 "content": "",
                 "content_raw": "",
                 "action": "created overview",
-                "origin": "all collections"
+                "origin": "all collections",
+                "extension": self.config["PAGE_EXT"]
             }
 
-            write_file(render_page(parse_meta([page])))
+            write_file(render_page(hook_plugins(parse_meta([page]))))
